@@ -99,6 +99,8 @@ class GrapheneUnshardedMeshSource(UnshardedLegacyPrecomputedMeshSource):
       bbox = Bbox.create(bbox)
       query_d['bounds'] = bbox.to_filename()
 
+    level = min(level, self.meta.max_meshed_layer)
+
     url = "%s/%s:%s" % (self.meta.meta.manifest_endpoint, segid, lod)
     if level is not None:
       res = requests.get(
@@ -131,8 +133,10 @@ class GrapheneUnshardedMeshSource(UnshardedLegacyPrecomputedMeshSource):
       an error.
     """
     import DracoPy
-
-    level = self.meta.meta.decode_layer_id(seg_id)
+    if bounding_box is not None:
+      level = 2
+    else:
+      level = self.meta.meta.decode_layer_id(seg_id)
     fragment_filenames = self.get_fragment_filenames(
       seg_id, level=level, bbox=bounding_box, bypass=bypass
     )
